@@ -32,6 +32,9 @@ install() {
     inst_hook pre-mount 30 "${moddir}/kiwi-dump-image.sh"
     inst_hook mount 30 "${moddir}/kiwi-mount-ramdisk.sh" 
 
+    inst_script "${moddir}/kiwi-ramdisk-deployment-generator.sh" \
+        "${systemdutildir}/system-generators/dracut-kiwi-ramdisk-generator"
+
     inst_rules 60-cdrom_id.rules
     dracut_need_initqueue
 }
