@@ -1,6 +1,8 @@
 #!/bin/bash
 # overlay images are specified with
 # root=overlay:UUID=uuid
+# root=overlay:PARTUUID=partuuid
+# root=overlay:LABEL=label
 # root=overlay:nbd=ip:exportname
 # root=overlay:aoe=interface
 
@@ -21,15 +23,30 @@ case "${overlayroot}" in
         root="${root#overlay:}"
         root="${root//\//\\x2f}"
         root="block:/dev/disk/by-uuid/${root#UUID=}"
+        rootok=1
+    ;;
+    overlay:PARTUUID=*|PARTUUID=*) \
+        root="${root#overlay:}"
+        root="${root//\//\\x2f}"
+        root="block:/dev/disk/by-partuuid/${root#PARTUUID=}"
+        rootok=1
+    ;;
+    overlay:LABEL=*|LABEL=*) \
+        root="${root#overlay:}"
+        root="${root//\//\\x2f}"
+        root="block:/dev/disk/by-label/${root#LABEL=}"
+        rootok=1
     ;;
     overlay:nbd=*) \
         root="block:/dev/nbd0"
         need_network=1
+        rootok=1
     ;;
     overlay:aoe=*) \
         root="${root#overlay:aoe=}"
         root="block:/dev/etherd/${root}"
         need_network=1
+        rootok=1
     ;;
 esac
 
@@ -40,9 +57,6 @@ if [ "${need_network}" = "1" ];then
     fi
 fi
 
-# Done, all good!
-rootok=1
-
 [ "${rootok}" = "1" ] || return 1
 
 info "root was ${overlayroot}, is now ${root}"
