@@ -12,6 +12,7 @@ for project in \
     Virtualization:Appliances:Images:Testing_x86:centos \
     Virtualization:Appliances:Images:Testing_x86:fedora \
     Virtualization:Appliances:Images:Testing_x86:ubuntu \
+    Virtualization:Appliances:Images:Testing_arm:ubuntu \
     Virtualization:Appliances:Images:Testing_x86:debian \
     Virtualization:Appliances:Images:Testing_s390:tumbleweed \
     Virtualization:Appliances:Images:Testing_s390:sle15 \
@@ -29,7 +30,11 @@ do
                 sed -e s@^F\ @'\\033[31mF \\e[0m'@ |\
                 sed -e s@^U\ @'\\033[33mU \\e[0m'@ |\
                 sed -e s@^D\ @'\\033[36mD \\e[0m'@ |\
-                sed -e s@^\\.@'\\033[32m.\\e[0m'@)"
+                sed -e s@^\\.@'\\033[32m.\\e[0m'@ |\
+                sed -e 's@^x\sF@x \\033[31mF\\e[0m'@ |\
+                sed -e 's@^x\sU@x \\033[33mU\\e[0m'@ |\
+                sed -e 's@^x\sD@x \\033[36mD\\e[0m'@ |\
+                sed -e 's@^x\s\.@x \\033[32m.\\e[0m'@)"
         done < <(osc -A https://api.opensuse.org \
             results -V "${project}" | sed -e 's@^(\s+)  test@D @' |\
             grep -B100 Legend | grep -v Legend
