@@ -55,6 +55,7 @@ class ContainerBuilder:
         self.requested_container_type = xml_state.get_build_type_name()
         self.base_image = None
         self.base_image_md5 = None
+        self.ensure_empty_tmpdirs = True
 
         self.container_config['xz_options'] = \
             self.custom_args.get('xz_options')
@@ -84,6 +85,9 @@ class ContainerBuilder:
                     )
                 )
 
+        if xml_state.build_type.get_ensure_empty_tmpdirs() is False:
+            self.ensure_empty_tmpdirs = False
+
         self.system_setup = SystemSetup(
             xml_state=xml_state, root_dir=self.root_dir
         )
@@ -140,7 +144,10 @@ class ContainerBuilder:
             self.requested_container_type, self.root_dir, self.container_config
         )
         self.filename = container_image.create(
-            self.filename, self.base_image
+            self.filename, self.base_image, self.ensure_empty_tmpdirs,
+            self.runtime_config.get_container_compression()
+            # appx containers already contains a compressed root
+            if self.requested_container_type != 'appx' else False
         )
         Result.verify_image_size(
             self.runtime_config.get_max_size_constraint(),
@@ -152,7 +159,7 @@ class ContainerBuilder:
             key='container',
             filename=self.filename,
             use_for_bundle=True,
-            compress=self.runtime_config.get_container_compression(),
+            compress=False,
             shasum=True
         )
         self.result.add(
