@@ -127,6 +127,7 @@ class DiskBuilder:
         self.force_mbr = xml_state.build_type.get_force_mbr()
         self.luks = xml_state.get_luks_credentials()
         self.integrity_root = xml_state.build_type.get_standalone_integrity()
+        self.integrity_legacy_hmac = xml_state.build_type.get_integrity_legacy_hmac()
         self.integrity_keyfile = xml_state.build_type.get_integrity_keyfile()
         self.integrity_key_description = \
             xml_state.build_type.get_integrity_metadata_key_description()
@@ -319,12 +320,16 @@ class DiskBuilder:
 
         # create integrity on current root device if requested
         if self.integrity_root:
+            options = []
+            if self.integrity_legacy_hmac:
+                options.append('legacy_hmac')
             self.integrity_root = IntegrityDevice(
                 device_map['root'], defaults.INTEGRITY_ALGORITHM,
                 integrity_credentials_type(
                     keydescription=self.integrity_key_description,
                     keyfile=self.integrity_keyfile,
-                    keyfile_algorithm=defaults.INTEGRITY_KEY_ALGORITHM
+                    keyfile_algorithm=defaults.INTEGRITY_KEY_ALGORITHM,
+                    options=options
                 )
             )
             self.integrity_root.create_dm_integrity()
