@@ -17,6 +17,7 @@
 #
 import os
 import logging
+from typing import Dict
 
 # project
 from kiwi.utils.temporary import Temporary
@@ -49,12 +50,12 @@ class ContainerImageAppx:
             'metadata_path': 'directory'
         }
     """
-    def __init__(self, root_dir, custom_args=None):
+    def __init__(self, root_dir: str, custom_args: Dict = {}):
         self.root_dir = root_dir
         self.wsl_config = custom_args or {}
         self.runtime_config = RuntimeConfig()
 
-        self.meta_data_path = self.wsl_config.get('metadata_path')
+        self.meta_data_path = format(self.wsl_config.get('metadata_path') or '')
 
         if not self.meta_data_path:
             raise KiwiContainerSetupError(
@@ -68,12 +69,17 @@ class ContainerImageAppx:
                 )
             )
 
-    def create(self, filename, base_image=None):
+    def create(
+        self, filename: str, base_image: str = '',
+        ensure_empty_tmpdirs: bool = False, compress_archive: bool = False
+    ):
         """
         Create WSL/Appx archive
 
         :param string filename: archive file name
         :param string base_image: not-supported
+        :param bool ensure_empty_tmpdirs: not-supported
+        :param bool compress_archive: compress container archive
         """
         exclude_list = Defaults.\
             get_exclude_list_for_root_data_sync() + Defaults.\
@@ -118,4 +124,9 @@ class ContainerImageAppx:
         Command.run(
             ['appx', '-o', filename, '-f', filemap_file.name]
         )
+        if compress_archive:
+            compress = Compress(filename)
+            compress.xz(self.runtime_config.get_xz_options())
+            filename = compress.compressed_filename
+
         return filename
