@@ -17,8 +17,13 @@
 #
 import os
 import logging
+from typing import (
+    Dict, List
+)
 
 # project
+from kiwi.utils.compress import Compress
+from kiwi.runtime_config import RuntimeConfig
 from kiwi.defaults import Defaults
 from kiwi.oci_tools import OCI
 
@@ -58,7 +63,7 @@ class ContainerImageOCI:
             }
         }
     """
-    def __init__(self, root_dir, transport, custom_args=None):
+    def __init__(self, root_dir: str, transport: str, custom_args: Dict = {}):
         self.root_dir = root_dir
         self.archive_transport = transport
         if custom_args:
@@ -97,15 +102,20 @@ class ContainerImageOCI:
             self.oci_config['history']['created_by'] = \
                 Defaults.get_default_container_created_by()
 
-    def create(self, filename, base_image):
+    def create(
+        self, filename: str, base_image: str,
+        ensure_empty_tmpdirs: bool = True, compress_archive: bool = False
+    ):
         """
         Create compressed oci system container tar archive
 
         :param string filename: archive file name
         :param string base_image: archive used as a base image
+        :param bool ensure_empty_tmpdirs: exclude system tmp directories
+        :param bool compress_archive: compress container archive
         """
         exclude_list = Defaults.\
-            get_exclude_list_for_root_data_sync() + Defaults.\
+            get_exclude_list_for_root_data_sync(ensure_empty_tmpdirs) + Defaults.\
             get_exclude_list_from_custom_exclude_files(self.root_dir)
         exclude_list.append('dev/*')
         exclude_list.append('sys/*')
@@ -140,7 +150,7 @@ class ContainerImageOCI:
             self.oci_config['container_name'],
             self.oci_config['container_tag']
         )
-        additional_refs = []
+        additional_refs: List[str] = []
         if self.archive_transport == 'docker-archive':
             if 'additional_names' in self.oci_config:
                 additional_refs = []
@@ -162,6 +172,10 @@ class ContainerImageOCI:
         oci.export_container_image(
             filename, self.archive_transport, image_ref, additional_refs
         )
+        if compress_archive:
+            compress = Compress(filename)
+            compress.xz(RuntimeConfig().get_xz_options())
+            filename = compress.compressed_filename
 
         return filename
 
