@@ -406,6 +406,12 @@ class KiwiLogFileSetupFailed(KiwiError):
     """
 
 
+class KiwiLogSocketSetupFailed(KiwiError):
+    """
+    Exception raised if the Unix Domain log socket could not be created.
+    """
+
+
 class KiwiLoopSetupError(KiwiError):
     """
     Exception raised if not enough user data to create a
@@ -835,3 +841,16 @@ class KiwiPartitionTooSmallError(KiwiError):
     Exception raised if the specified partition size is smaller
     than the required bytes to store the data
     """
+
+
+class KiwiCredentialsError(KiwiError):
+    """
+    Exception raised if required credentials information is missing
+    """
+
+
+class KiwiOffsetError(KiwiError):
+    """
+    Exception raised if the offset for a seek operation does not
+    match the expected data to write
+    """
