@@ -110,6 +110,19 @@ class FileSystemBase:
         if not self.custom_args.get('fs_attributes'):
             self.custom_args['fs_attributes'] = []
 
+    def set_uuid(self):
+        """
+        Create new random filesystem UUID
+
+        Implement in specialized filesystem class for filesystems which
+        supports the concept of an UUID and allows to change it
+        """
+        log.warning(
+            'Instance {0} has no support for setting a new UUID label'.format(
+                type(self).__name__
+            )
+        )
+
     def create_on_device(
         self, label: str = None, size: int = 0, unit: str = defaults.UNIT.kb,
         uuid: str = None
@@ -232,14 +245,22 @@ class FileSystemBase:
                 device_node or self.device_provider.get_device()
             )
 
-    def umount(self):
+    def mount(self) -> None:
+        """
+        Mount the filesystem
+        """
+        if self.filesystem_mount:
+            self.filesystem_mount.mount(
+                self.custom_args['mount_options']
+            )
+
+    def umount(self) -> None:
         """
         Umounts the filesystem in case it is mounted, does nothing otherwise
         """
         if self.filesystem_mount:
             log.info('umount %s instance', type(self).__name__)
             self.filesystem_mount.umount()
-            self.filesystem_mount = None
 
     def _map_size(self, size: float, from_unit: str, to_unit: str) -> float:
         """
