@@ -154,12 +154,13 @@ class PackageManagerMicroDnf(PackageManagerBase):
             )
 
     def process_install_requests_bootstrap(
-        self, root_bind: RootBind = None
+        self, root_bind: RootBind = None, bootstrap_package: str = None
     ) -> command_call_type:
         """
         Process package install requests for bootstrap phase (no chroot)
 
         :param object root_bind: unused
+        :param str bootstrap_package: unused
 
         :return: process results in command type
 
@@ -356,6 +357,7 @@ class PackageManagerMicroDnf(PackageManagerBase):
         """
         rpmdb = RpmDataBase(self.root_dir)
         if rpmdb.has_rpm():
+            rpmdb.rebuild_database()
             rpmdb.set_database_to_image_path()
 
     def clean_leftovers(self) -> None:
