@@ -579,6 +579,24 @@ class XMLState:
                     result.append(package.get_name().strip())
         return sorted(result)
 
+    def get_bootstrap_package_name(self) -> str:
+        """
+        bootstrap_package name from type="bootstrap" packages section
+
+        :return: bootstrap_package name
+
+        :rtype: str
+        """
+        typed_packages_sections = self.get_packages_sections(
+            ['bootstrap', self.get_build_type_name()]
+        )
+        bootstrap_package = ''
+        for packages in typed_packages_sections:
+            bootstrap_package = packages.get_bootstrap_package()
+            if bootstrap_package:
+                break
+        return bootstrap_package
+
     def get_collection_type(self, section_type: str = 'image') -> str:
         """
         Collection type from packages sections matching given section
@@ -1266,13 +1284,14 @@ class XMLState:
 
         return users_list
 
-    def get_user_groups(self, user_name) -> List:
+    def get_user_groups(self, user_name) -> List[str]:
         """
         List of group names matching specified user
 
-        Each entry in the list is the name of a group that the specified
-        user belongs to. The first item in the list is the login or primary
-        group. The list will be empty if no groups are specified in the
+        Each entry in the list is the name of a group and optionally its
+        group ID separated by a colon, that the specified user belongs to.
+        The first item in the list is the login or primary group. The
+        list will be empty if no groups are specified in the
         description file.
 
         :return: groups data for the given user
@@ -1418,6 +1437,7 @@ class XMLState:
                 {
                     'NAME': ptable_entry_type(
                         mbsize=int,
+                        clone=int,
                         partition_name=str,
                         partition_type=str,
                         mountpoint=str,
@@ -1436,6 +1456,7 @@ class XMLState:
             partition_name = partition.get_partition_name() or f'p.lx{name}'
             partitions[name] = ptable_entry_type(
                 mbsize=self._to_mega_byte(partition.get_size()),
+                clone=int(partition.get_clone()) if partition.get_clone() else 0,
                 partition_name=partition_name,
                 partition_type=partition.get_partition_type() or 't.linux',
                 mountpoint=partition.get_mountpoint(),
@@ -1790,7 +1811,9 @@ class XMLState:
     def set_repository(
         self, repo_source: str, repo_type: str, repo_alias: str,
         repo_prio: str, repo_imageinclude: bool = False,
-        repo_package_gpgcheck: Optional[bool] = None
+        repo_package_gpgcheck: Optional[bool] = None,
+        repo_signing_keys: List[str] = [], components: str = None,
+        distribution: str = None, repo_gpgcheck: Optional[bool] = None
     ) -> None:
         """
         Overwrite repository data of the first repository
@@ -1801,6 +1824,10 @@ class XMLState:
         :param str repo_prio: priority number, package manager specific
         :param bool repo_imageinclude: setup repository inside of the image
         :param bool repo_package_gpgcheck: enable/disable package gpg checks
+        :param list repo_signing_keys: list of signing key file names
+        :param str components: component names for debian repos
+        :param str distribution: base distribution name for debian repos
+        :param bool repo_gpgcheck: enable/disable repo gpg checks
         """
         repository_sections = self.get_repository_sections()
         if repository_sections:
@@ -1817,12 +1844,23 @@ class XMLState:
                 repository.set_imageinclude(repo_imageinclude)
             if repo_package_gpgcheck is not None:
                 repository.set_package_gpgcheck(repo_package_gpgcheck)
+            if repo_signing_keys:
+                repository.get_source().set_signing(
+                    [xml_parse.signing(key=k) for k in repo_signing_keys]
+                )
+            if components:
+                repository.set_components(components)
+            if distribution:
+                repository.set_distribution(distribution)
+            if repo_gpgcheck is not None:
+                repository.set_repository_gpgcheck(repo_gpgcheck)
 
     def add_repository(
         self, repo_source: str, repo_type: str, repo_alias: str = None,
         repo_prio: str = '', repo_imageinclude: bool = False,
         repo_package_gpgcheck: Optional[bool] = None,
-        repo_signing_keys: List[str] = []
+        repo_signing_keys: List[str] = [], components: str = None,
+        distribution: str = None, repo_gpgcheck: Optional[bool] = None
     ) -> None:
         """
         Add a new repository section at the end of the list
@@ -1833,6 +1871,10 @@ class XMLState:
         :param str repo_prio: priority number, package manager specific
         :param bool repo_imageinclude: setup repository inside of the image
         :param bool repo_package_gpgcheck: enable/disable package gpg checks
+        :param list repo_signing_keys: list of signing key file names
+        :param str components: component names for debian repos
+        :param str distribution: base distribution name for debian repos
+        :param bool repo_gpgcheck: enable/disable repo gpg checks
         """
         priority_number: Optional[int] = None
         try:
@@ -1852,7 +1894,10 @@ class XMLState:
                     ]
                 ),
                 imageinclude=repo_imageinclude,
-                package_gpgcheck=repo_package_gpgcheck
+                package_gpgcheck=repo_package_gpgcheck,
+                repository_gpgcheck=repo_gpgcheck,
+                components=components,
+                distribution=distribution
             )
         )
 
