@@ -124,6 +124,36 @@ class TestBootLoaderConfigBase:
         assert self.bootloader.get_boot_cmdline('uuid') == \
             'splash root=UUID=uuid'
 
+    @patch('kiwi.xml_parse.type_.get_initrd_system')
+    @patch('kiwi.bootloader.config.base.BlockID')
+    def test_get_boot_cmdline_initrd_system_is_dracut_partuuid(
+        self, mock_BlockID, mock_initrd
+    ):
+        block_operation = Mock()
+        block_operation.get_blkid.return_value = 'uuid'
+        mock_BlockID.return_value = block_operation
+        mock_initrd.return_value = 'dracut'
+        self.bootloader.xml_state.build_type.set_devicepersistency(
+            'by-partuuid'
+        )
+        assert self.bootloader.get_boot_cmdline('uuid') == \
+            'splash root=PARTUUID=uuid'
+
+    @patch('kiwi.xml_parse.type_.get_initrd_system')
+    @patch('kiwi.bootloader.config.base.BlockID')
+    def test_get_boot_cmdline_initrd_system_is_dracut_label(
+        self, mock_BlockID, mock_initrd
+    ):
+        block_operation = Mock()
+        block_operation.get_blkid.return_value = 'label'
+        mock_BlockID.return_value = block_operation
+        mock_initrd.return_value = 'dracut'
+        self.bootloader.xml_state.build_type.set_devicepersistency(
+            'by-label'
+        )
+        assert self.bootloader.get_boot_cmdline('uuid') == \
+            'splash root=LABEL=label'
+
     @patch('kiwi.xml_parse.type_.get_initrd_system')
     @patch('kiwi.bootloader.config.base.BlockID')
     def test_get_boot_cmdline_initrd_system_is_dracut_with_overlay(
@@ -282,6 +312,7 @@ class TestBootLoaderConfigBase:
     def test_mount_system_s390(self, mock_MountManager):
         tmp_mount = MagicMock()
         proc_mount = MagicMock()
+        sys_mount = MagicMock()
         dev_mount = MagicMock()
         root_mount = MagicMock()
         root_mount.mountpoint = 'root_mount_point'
@@ -290,7 +321,7 @@ class TestBootLoaderConfigBase:
         boot_mount.device = 'bootdev'
 
         mount_managers = [
-            proc_mount, dev_mount, tmp_mount, boot_mount, root_mount
+            proc_mount, sys_mount, dev_mount, tmp_mount, boot_mount, root_mount
         ]
 
         def mount_managers_effect(**args):
@@ -306,13 +337,15 @@ class TestBootLoaderConfigBase:
             call(device='rootdev'),
             call(device='bootdev', mountpoint='root_mount_point/boot/zipl'),
             call(device='/dev', mountpoint='root_mount_point/dev'),
-            call(device='/proc', mountpoint='root_mount_point/proc')
+            call(device='/proc', mountpoint='root_mount_point/proc'),
+            call(device='/sys', mountpoint='root_mount_point/sys')
         ]
 
     @patch('kiwi.bootloader.config.base.MountManager')
     def test_mount_system(self, mock_MountManager):
         tmp_mount = MagicMock()
         proc_mount = MagicMock()
+        sys_mount = MagicMock()
         dev_mount = MagicMock()
         root_mount = MagicMock()
         root_mount.mountpoint = 'root_mount_point'
@@ -324,7 +357,7 @@ class TestBootLoaderConfigBase:
         volume_mount = MagicMock()
 
         mount_managers = [
-            proc_mount, dev_mount, tmp_mount, volume_mount,
+            proc_mount, sys_mount, dev_mount, tmp_mount, volume_mount,
             efi_mount, boot_mount, root_mount
         ]
 
@@ -348,7 +381,8 @@ class TestBootLoaderConfigBase:
             call(device='device', mountpoint='root_mount_point/boot/grub2'),
             call(device='/tmp', mountpoint='root_mount_point/tmp'),
             call(device='/dev', mountpoint='root_mount_point/dev'),
-            call(device='/proc', mountpoint='root_mount_point/proc')
+            call(device='/proc', mountpoint='root_mount_point/proc'),
+            call(device='/sys', mountpoint='root_mount_point/sys')
         ]
         root_mount.mount.assert_called_once_with()
         boot_mount.mount.assert_called_once_with()
@@ -357,6 +391,7 @@ class TestBootLoaderConfigBase:
             options=['subvol=@/boot/grub2']
         )
         proc_mount.bind_mount.assert_called_once_with()
+        sys_mount.bind_mount.assert_called_once_with()
         dev_mount.bind_mount.assert_called_once_with()
 
         del self.bootloader
@@ -365,6 +400,7 @@ class TestBootLoaderConfigBase:
         tmp_mount.umount.assert_called_once_with()
         dev_mount.umount.assert_called_once_with()
         proc_mount.umount.assert_called_once_with()
+        sys_mount.umount.assert_called_once_with()
         efi_mount.umount.assert_called_once_with()
         boot_mount.umount.assert_called_once_with()
         root_mount.umount.assert_called_once_with()
