@@ -19,7 +19,7 @@ class TestKisBuilder:
 
     @patch('kiwi.builder.kis.FileSystemBuilder')
     @patch('kiwi.builder.kis.BootImage')
-    def setup(self, mock_KisBuilder, mock_boot, mock_filesystem):
+    def setup(self, mock_boot, mock_filesystem):
         self.setup = Mock()
         self.runtime_config = Mock()
         self.runtime_config.get_max_size_constraint = Mock(
@@ -77,6 +77,11 @@ class TestKisBuilder:
         self.kis.image_name = 'myimage'
         self.kis.compressed = True
 
+    @patch('kiwi.builder.kis.FileSystemBuilder')
+    @patch('kiwi.builder.kis.BootImage')
+    def setup_method(self, cls, mock_boot, mock_filesystem):
+        self.setup()
+
     @patch('kiwi.builder.kis.FileSystemBuilder')
     @patch('kiwi.builder.kis.BootImage')
     def test_setup_warn_no_initrd_support(self, mock_boot, mock_filesystem):
