@@ -9,25 +9,25 @@ from kiwi.exceptions import KiwiContainerImageSetupError
 class TestContainerImage:
     def test_container_image_not_implemented(self):
         with raises(KiwiContainerImageSetupError):
-            ContainerImage('foo', 'root_dir')
+            ContainerImage.new('foo', 'root_dir')
 
-    @patch('kiwi.container.ContainerImageOCI')
+    @patch('kiwi.container.oci.ContainerImageOCI')
     def test_container_image_docker(self, mock_docker):
-        ContainerImage('docker', 'root_dir')
+        ContainerImage.new('docker', 'root_dir')
         mock_docker.assert_called_once_with(
-            'root_dir', 'docker-archive', custom_args=None
+            'root_dir', 'docker-archive', None
         )
 
-    @patch('kiwi.container.ContainerImageOCI')
+    @patch('kiwi.container.oci.ContainerImageOCI')
     def test_container_image_oci(self, mock_oci):
-        ContainerImage('oci', 'root_dir')
+        ContainerImage.new('oci', 'root_dir')
         mock_oci.assert_called_once_with(
-            'root_dir', 'oci-archive', custom_args=None
+            'root_dir', 'oci-archive', None
         )
 
-    @patch('kiwi.container.ContainerImageAppx')
+    @patch('kiwi.container.appx.ContainerImageAppx')
     def test_container_image_appx(self, mock_appx):
-        ContainerImage('appx', 'root_dir')
+        ContainerImage.new('appx', 'root_dir')
         mock_appx.assert_called_once_with(
-            'root_dir', custom_args=None
+            'root_dir', None
         )
