@@ -7,7 +7,7 @@ from kiwi.container.setup.oci import ContainerSetupOCI
 
 class TestContainerSetupOCI:
     @patch('os.path.exists')
-    def setup(self, mock_ContainerSetupOCI, mock_exists):
+    def setup(self, mock_exists):
         mock_exists.return_value = True
 
         self.container = ContainerSetupOCI(
@@ -16,15 +16,17 @@ class TestContainerSetupOCI:
 
         self.container.deactivate_bootloader_setup = mock.Mock()
         self.container.deactivate_root_filesystem_check = mock.Mock()
-        self.container.setup_static_device_nodes = mock.Mock()
         self.container.setup_root_console = mock.Mock()
         self.container.deactivate_systemd_service = mock.Mock()
 
+    @patch('os.path.exists')
+    def setup_method(self, cls, mock_exists):
+        self.setup()
+
     def test_setup(self):
         self.container.setup()
         self.container.deactivate_bootloader_setup.assert_called_once_with()
         self.container.deactivate_root_filesystem_check.assert_called_once_with()
-        self.container.setup_static_device_nodes.assert_called_once_with()
         assert self.container.deactivate_systemd_service.call_args_list == [
             call('device-mapper.service'),
             call('kbd.service'),
