@@ -6,7 +6,10 @@ from pytest import raises
 
 from kiwi.logger import Logger
 
-from kiwi.exceptions import KiwiLogFileSetupFailed
+from kiwi.exceptions import (
+    KiwiLogFileSetupFailed,
+    KiwiLogSocketSetupFailed
+)
 
 
 class TestLogger:
@@ -35,6 +38,13 @@ class TestLogger:
         )
         assert self.log.get_logfile() == 'logfile'
 
+    @patch('kiwi.logger.PlainTextSocketHandler')
+    def test_set_log_socket(self, mock_socket_handler):
+        self.log.set_log_socket('socketfile')
+        mock_socket_handler.assert_called_once_with(
+            'socketfile', None
+        )
+
     @patch('logging.StreamHandler')
     def test_set_logfile_to_stdout(self, mock_stream_handler):
         self.log.set_logfile('stdout')
@@ -67,6 +77,12 @@ class TestLogger:
         with raises(KiwiLogFileSetupFailed):
             self.log.set_logfile('logfile')
 
+    @patch('kiwi.logger.PlainTextSocketHandler')
+    def test_set_log_socket_raise(self, mock_socket_handler):
+        mock_socket_handler.side_effect = KiwiLogSocketSetupFailed
+        with raises(KiwiLogSocketSetupFailed):
+            self.log.set_log_socket('socketfile')
+
     def test_getLogLevel(self):
         self.log.setLogLevel(42)
         assert self.log.getLogLevel() == 42
