@@ -22,6 +22,9 @@ class TestPackageManagerDnf:
         )
         self.manager = PackageManagerDnf(repository)
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_request_package(self):
         self.manager.request_package('name')
         assert self.manager.package_requests == ['name']
@@ -188,6 +191,7 @@ class TestPackageManagerDnf:
         rpmdb.has_rpm.return_value = True
         mock_RpmDataBase.return_value = rpmdb
         self.manager.post_process_install_requests_bootstrap()
+        rpmdb.rebuild_database.assert_called_once_with()
         rpmdb.set_database_to_image_path.assert_called_once_with()
 
     @patch('kiwi.package_manager.dnf.Rpm')
