@@ -14,8 +14,7 @@ from kiwi.exceptions import KiwiCommandError
 class TestRepositoryZypper:
     @patch('kiwi.command.Command.run')
     @patch('kiwi.repository.zypper.Temporary.new_file')
-    def setup(self, mock_RepositoryZypper, mock_temp, mock_command):
-
+    def setup(self, mock_temp, mock_command):
         self.context_manager_mock = mock.Mock()
         self.file_mock = mock.Mock()
         self.enter_mock = mock.Mock()
@@ -35,6 +34,11 @@ class TestRepositoryZypper:
                 self.root_bind, ['exclude_docs', '_install_langs%en_US:de_DE']
             )
 
+    @patch('kiwi.command.Command.run')
+    @patch('kiwi.repository.zypper.Temporary.new_file')
+    def setup_method(self, cls, mock_temp, mock_command):
+        self.setup()
+
     @patch('kiwi.command.Command.run')
     @patch('kiwi.repository.zypper.Temporary.new_file')
     def test_custom_args_init_excludedocs(self, mock_temp, mock_command):
