@@ -19,7 +19,8 @@ from kiwi.defaults import Defaults
 
 from kiwi.exceptions import (
     KiwiScriptFailed,
-    KiwiImportDescriptionError
+    KiwiImportDescriptionError,
+    KiwiFileNotFound
 )
 
 
@@ -40,6 +41,9 @@ class TestSystemSetup:
         self.xml_state.get_package_manager = Mock(
             return_value='zypper'
         )
+        self.xml_state.build_type.get_selinux_policy = Mock(
+            return_value=None
+        )
         self.xml_state.build_type.get_filesystem = Mock(
             return_value='ext3'
         )
@@ -69,6 +73,9 @@ class TestSystemSetup:
             error='stderr',
             returncode=0
         )
+        self.selinux_policies = os.scandir(
+            '../data/etc/selinux/targeted/policy'
+        )
 
     @patch('kiwi.system.setup.RuntimeConfig')
     def setup_method(self, cls, mock_RuntimeConfig):
@@ -423,7 +430,9 @@ class TestSystemSetup:
         ])
 
     @patch('os.path.exists')
-    def test_setup_keyboard_skipped(self, mock_exists):
+    @patch('kiwi.system.setup.CommandCapabilities.has_option_in_help')
+    def test_setup_keyboard_skipped(self, mock_caps, mock_exists):
+        mock_caps.return_value = False
         mock_exists.return_value = False
         self.setup.preferences['keytable'] = 'keytable'
         with self._caplog.at_level(logging.WARNING):
@@ -1377,16 +1386,60 @@ class TestSystemSetup:
             raise_on_error=False
         )
 
+    @patch('kiwi.system.setup.CommandCapabilities.has_option_in_help')
     @patch('kiwi.system.setup.Command.run')
-    def test_set_selinux_file_contexts(self, mock_command):
+    @patch('os.scandir')
+    def test_set_selinux_file_contexts_new_version(
+        self, mock_os_scandir, mock_command, mock_has_option_in_help
+    ):
+        mock_has_option_in_help.return_value = False
+        mock_os_scandir.return_value = self.selinux_policies
         self.setup.set_selinux_file_contexts('security_context_file')
         mock_command.assert_called_once_with(
             [
                 'chroot', 'root_dir',
-                'setfiles', 'security_context_file', '/', '-v', '-F'
+                'setfiles', '-F', '-p',
+                '-c', '/etc/selinux/targeted/policy/policy.some_policy',
+                '-e', '/proc', '-e', '/sys', '-e', '/dev',
+                'security_context_file', '/'
             ]
         )
 
+    @patch('kiwi.system.setup.CommandCapabilities.has_option_in_help')
+    @patch('kiwi.system.setup.Command.run')
+    @patch('os.scandir')
+    def test_set_selinux_file_contexts_old_version(
+        self, mock_os_scandir, mock_command, mock_has_option_in_help
+    ):
+        mock_has_option_in_help.return_value = True
+        mock_os_scandir.return_value = self.selinux_policies
+        self.setup.set_selinux_file_contexts('security_context_file')
+        assert mock_command.call_args_list == [
+            call(
+                [
+                    'chroot', 'root_dir', 'setfiles', '-c',
+                    '/etc/selinux/targeted/policy/policy.some_policy',
+                    'security_context_file'
+                ]
+            ),
+            call(
+                [
+                    'chroot', 'root_dir', 'setfiles', '-F', '-p',
+                    '-e', '/proc', '-e', '/sys', '-e', '/dev',
+                    'security_context_file', '/'
+                ]
+            )
+        ]
+
+    @patch('kiwi.system.setup.Command.run')
+    @patch('os.scandir')
+    def test_set_selinux_file_contexts_raises(
+        self, mock_os_scandir, mock_command
+    ):
+        mock_os_scandir.side_effect = Exception
+        with raises(KiwiFileNotFound):
+            self.setup.set_selinux_file_contexts('security_context_file')
+
     @patch('os.path.exists')
     @patch.object(SystemSetup, 'set_selinux_file_contexts')
     def test_setup_selinux_file_contexts(
