@@ -85,7 +85,9 @@ class TestSystemPrepareTask:
         self.task.command_args['--root'] = '../data/root-dir'
         self.task.command_args['--allow-existing-root'] = False
         self.task.command_args['--set-repo'] = None
+        self.task.command_args['--set-repo-credentials'] = None
         self.task.command_args['--add-repo'] = []
+        self.task.command_args['--add-repo-credentials'] = []
         self.task.command_args['--add-package'] = []
         self.task.command_args['--add-bootstrap-package'] = []
         self.task.command_args['--delete-package'] = []
@@ -177,6 +179,7 @@ class TestSystemPrepareTask:
         self.setup.setup_plymouth_splash.assert_called_once_with()
         self.setup.setup_timezone.assert_called_once_with()
         self.setup.setup_permissions.assert_called_once_with()
+        self.setup.setup_selinux_file_contexts.assert_called_once_with()
 
         self.system_prepare.pinch_system.assert_has_calls(
             [call(force=False), call(force=True)]
@@ -269,26 +272,79 @@ class TestSystemPrepareTask:
         )
 
     @patch('kiwi.xml_state.XMLState.set_repository')
-    def test_process_system_prepare_set_repo(self, mock_state):
+    @patch('os.path.isfile')
+    @patch('os.unlink')
+    def test_process_system_prepare_set_repo(
+        self, mock_os_unlink, mock_os_path_is_file, mock_set_repo
+    ):
+        mock_os_path_is_file.return_value = False
         self._init_command_args()
         self.task.command_args['--set-repo'] = 'http://example.com,yast2,alias'
         self.task.process()
-        mock_state.assert_called_once_with(
+        mock_set_repo.assert_called_once_with(
             'http://example.com', 'yast2', 'alias',
             None, None, None, [], None, None, None
         )
+        self.task.command_args['--set-repo-credentials'] = 'user:pass'
+        mock_set_repo.reset_mock()
+        self.task.process()
+        mock_set_repo.assert_called_once_with(
+            'http://user:pass@example.com', 'yast2', 'alias',
+            None, None, None, [], None, None, None
+        )
+        self.task.command_args['--set-repo-credentials'] = '../data/credentials'
+        mock_os_path_is_file.return_value = True
+        mock_set_repo.reset_mock()
+        self.task.process()
+        mock_set_repo.assert_called_once_with(
+            'http://user:pass@example.com', 'yast2', 'alias',
+            None, None, None, [], None, None, None
+        )
+        mock_os_unlink.assert_called_once_with('../data/credentials')
 
     @patch('kiwi.xml_state.XMLState.add_repository')
-    def test_process_system_prepare_add_repo(self, mock_state):
+    def test_process_system_prepare_add_repo(self, mock_add_repo):
         self._init_command_args()
         self.task.command_args['--add-repo'] = [
-            'http://example.com,yast2,alias,99,true'
+            'http://example1.com,yast2,alias,99,true',
+            'http://example2.com,yast2,alias,99,false,true',
+            'http://example3.com,yast2,alias,99,false,true'
         ]
         self.task.process()
-        mock_state.assert_called_once_with(
-            'http://example.com', 'yast2', 'alias', '99',
-            True, None, [], None, None, None
-        )
+        assert mock_add_repo.call_args_list == [
+            call(
+                'http://example1.com', 'yast2', 'alias', '99',
+                True, None, [], None, None, None
+            ),
+            call(
+                'http://example2.com', 'yast2', 'alias', '99',
+                False, True, [], None, None, None
+            ),
+            call(
+                'http://example3.com', 'yast2', 'alias', '99',
+                False, True, [], None, None, None
+            )
+        ]
+        self.task.command_args['--add-repo-credentials'] = [
+            'user1:pass1',
+            'user2:pass2'
+        ]
+        mock_add_repo.reset_mock()
+        self.task.process()
+        assert mock_add_repo.call_args_list == [
+            call(
+                'http://user1:pass1@example1.com', 'yast2', 'alias', '99',
+                True, None, [], None, None, None
+            ),
+            call(
+                'http://user2:pass2@example2.com', 'yast2', 'alias', '99',
+                False, True, [], None, None, None
+            ),
+            call(
+                'http://example3.com', 'yast2', 'alias', '99',
+                False, True, [], None, None, None
+            )
+        ]
 
     def test_process_system_prepare_help(self):
         self._init_command_args()
