@@ -1,4 +1,6 @@
-from mock import patch
+from mock import (
+    Mock, patch
+)
 
 from kiwi.utils.block import BlockID
 
@@ -21,7 +23,8 @@ class TestBlockID:
     def test_get_blkid(self, mock_command):
         self.blkid.get_blkid('LABEL')
         mock_command.assert_called_once_with(
-            ['blkid', 'device', '-s', 'LABEL', '-o', 'value']
+            ['blkid', 'device', '-s', 'LABEL', '-o', 'value'],
+            raise_on_error=False
         )
 
     @patch('kiwi.utils.block.BlockID.get_blkid')
@@ -38,3 +41,10 @@ class TestBlockID:
     def test_get_uuid(self, mock_get_blkid):
         self.blkid.get_uuid()
         mock_get_blkid.assert_called_once_with('UUID')
+
+    @patch('kiwi.utils.block.Command.run')
+    def test_get_partition_count(self, mock_Command_run):
+        lsblk_call = Mock()
+        lsblk_call.output = "NAME TYPE\nsda disk\nsda4 part \nsda3 part"
+        mock_Command_run.return_value = lsblk_call
+        assert self.blkid.get_partition_count() == 2
