@@ -35,6 +35,12 @@ class TestXMLState:
         self.state = XMLState(
             self.description.load()
         )
+        apt_description = XMLDescription(
+            '../data/example_apt_config.xml'
+        )
+        self.apt_state = XMLState(
+            apt_description.load()
+        )
         boot_description = XMLDescription(
             '../data/isoboot/example-distribution/config.xml'
         )
@@ -202,7 +208,10 @@ class TestXMLState:
         assert self.state.get_bootstrap_collection_type() == 'onlyRequired'
 
     def test_set_repository(self):
-        self.state.set_repository('repo', 'type', 'alias', 1, True, False)
+        self.state.set_repository(
+            'repo', 'type', 'alias', 1, True, False, ['key_a', 'key_b'],
+            'main universe', 'jammy', False
+        )
         assert self.state.xml_data.get_repository()[0].get_source().get_path() \
             == 'repo'
         assert self.state.xml_data.get_repository()[0].get_type() == 'type'
@@ -212,9 +221,22 @@ class TestXMLState:
             .get_imageinclude() is True
         assert self.state.xml_data.get_repository()[0] \
             .get_package_gpgcheck() is False
+        assert self.state.xml_data.get_repository()[0] \
+            .get_source().get_signing()[0].get_key() == 'key_a'
+        assert self.state.xml_data.get_repository()[0] \
+            .get_source().get_signing()[1].get_key() == 'key_b'
+        assert self.state.xml_data.get_repository()[0].get_components() \
+            == 'main universe'
+        assert self.state.xml_data.get_repository()[0].get_distribution() \
+            == 'jammy'
+        assert self.state.xml_data.get_repository()[0] \
+            .get_repository_gpgcheck() is False
 
     def test_add_repository(self):
-        self.state.add_repository('repo', 'type', 'alias', 1, True)
+        self.state.add_repository(
+            'repo', 'type', 'alias', 1, True, None, ['key_a', 'key_b'],
+            'main universe', 'jammy', False
+        )
         assert self.state.xml_data.get_repository()[3].get_source().get_path() \
             == 'repo'
         assert self.state.xml_data.get_repository()[3].get_type() == 'type'
@@ -222,6 +244,16 @@ class TestXMLState:
         assert self.state.xml_data.get_repository()[3].get_priority() == 1
         assert self.state.xml_data.get_repository()[3] \
             .get_imageinclude() is True
+        assert self.state.xml_data.get_repository()[3] \
+            .get_source().get_signing()[0].get_key() == 'key_a'
+        assert self.state.xml_data.get_repository()[3] \
+            .get_source().get_signing()[1].get_key() == 'key_b'
+        assert self.state.xml_data.get_repository()[3].get_components() \
+            == 'main universe'
+        assert self.state.xml_data.get_repository()[3].get_distribution() \
+            == 'jammy'
+        assert self.state.xml_data.get_repository()[3] \
+            .get_repository_gpgcheck() is False
 
     def test_add_repository_with_empty_values(self):
         self.state.add_repository('repo', 'type', '', '', True)
@@ -330,6 +362,7 @@ class TestXMLState:
         assert state.get_partitions() == {
             'var': ptable_entry_type(
                 mbsize=100,
+                clone=0,
                 partition_name='p.lxvar',
                 partition_type='t.linux',
                 mountpoint='/var',
@@ -1063,3 +1096,6 @@ class TestXMLState:
             '--cipher', 'aes-gcm-random',
             '--integrity', 'aead'
         ]
+
+    def test_get_bootstrap_package_name(self):
+        assert self.apt_state.get_bootstrap_package_name() == 'bootstrap-me'
